summaryrefslogtreecommitdiff
path: root/lib/action.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/action.php')
-rw-r--r--lib/action.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/action.php b/lib/action.php
index 16959c53a..7a2461bb5 100644
--- a/lib/action.php
+++ b/lib/action.php
@@ -28,7 +28,7 @@ class Action { // lawsuit
# For initializing members of the class
- function init($argarray) {
+ function prepare($argarray) {
$this->args =& common_copy_args($argarray);
return true;
}
@@ -61,7 +61,7 @@ class Action { // lawsuit
return (is_string($arg)) ? trim($arg) : $arg;
}
# Note: argarray ignored, since it's now passed in in init()
function handle($argarray=NULL) {
@@ -61,7 +61,7 @@ class Action { // lawsuit
return (is_string($arg)) ? trim($arg) : $arg;
}
- # Note: argarray ignored, since it's now passed in in init()
+ # Note: argarray ignored, since it's now passed in in prepare()
function handle($argarray=NULL) {